@@ -1,6 +1,6 @@
 import helper
 
-test_modules = ['fetchers']
+test_modules = ['fetchers', 'urinorm']
 
 def getTestCases():
     tests = []
